# Systematic Literature Review: A Revised Structure
:::info
Provide a structured summary including, as applicable: background; objectives; data sources; study eligibility criteria, participants, and interventions; study appraisal and synthesis methods; results; limitations; conclusions and implications of key findings; systematic review registration number.
       
:::

## 1. Introduction
### 1.1. Background
**VGI has emerged since the era of Web2.0.** 
* Volunteering geographic information (VGI) or geographic crowdsourcing has been beneficial to our society with regard to gathering adequate information where one cannot acquire from.
* "VGI is, in a sense, postmodern GIS, in which individuals are able to assert their own views of their surroundings and play a part in local decision making" [(Goodchild, 2007)](https://www.esri.com/news/arcuser/0410/vgi.html).


**The role of crowd has become more important than ever.**
* According to [Brown (2017)](https://onlinelibrary.wiley.com/doi/full/10.1111/tgis.12207), crowd, in the context of VGI, is defined as the public whose interests are in spatial information and technology, and can willingly devote their time to create up-to-date and accurate resources to help the readers. 
* It is very much dependent on local economic conditions and the quality of life.
* Crowd can be distinguished into three groups: 1) by the type of people, 2) by geographic boundaries, 3) by the internet users.
    - Type of People: Decision makers, stakeholders, implementers, interested observers, and the random public
    - Geography: within a spatial boundary, local people with spatial-cognitive knowledge about their neighbourhood
    - Internet users: An online population


**The Under-represented Crowds**
* Who are they: 
    * A silent minority who needs information about public facilities
    * A community with local knowledge but weakness in internet technology
    * A population that has restrictions on the update due to language or censoring issues 
* The oppposite group:
    * The elite, western, english-speaking male ([Gardens, 2020](https://link.springer.com/article/10.1007/s10708-019-10035-z); [Haworth, 2018](https://www.frontiersin.org/article/10.3389/feart.2018.00183))
    * System development and maintenance is mainly done by them

**Why should we consider under-represented crowds in VGI studies?**
* To improve spatial mapping bias
    * Mapped areas get more attention and information while others don’t 
    * For example, Europe & N.America vs Rest of the world; Urban vs Rural
    * Level of expertise can vary: people with geographical knowledge
* To fill missing data
    * Names in the local areas are different from the officially recognized names that appear on maps  
    * Political and social marginalization of those left off the map (Elwood, 2008).
    * Hidden data may be regarded as least important → neglect social support


------
### 1.2. Rationale

**Critiques from Previous Studies**
* Biased samples have been thoroughly discussed in previous papers, but the context was either to assess the likelihood of imbalance between groups (quantitatively or qualitatively) or have raised sampling errors that is statistically not accepted
* Studies are often focused on one particular topic in isolation thus does not make it suitable in all applications
* To our knowledge, none of the published reviews identified or analysed the available evidence from a strict systematic approach. To get more ideas of which under-represented group is highlighted, this review will not constrain the discipline nor type of platforms


### 1.3. **Research Objective**
This paper conducts a systematic review to identify and analyse the main components of under-represented participants in various VGI projects and the outlook to encourage diverse participation in future geospatial crowdsourcing. 


**Research Questions (SPICE Framework):**

We formulated the following research questions according to the SPICE framework, which is widely used in social science research ([Booth, 2006](https://doi.org/10.1108/07378830610692127)).

Does the contribution of under-represented volunteers (participants) more likely to create diverse outcomes in VGI projects when compared with the socially biased environment? *Please refer to the following link for SPICE analytics* → [Click](/DEm8Wy6HTBWC19YV0aTLPQ)


* What discipline or journal type have published VGI projects? What are their themes?
* What are the differences of the under-represented groups in the output?
* Do we see any difference in the map? (sampling bias does matter!)
* Which demographic or non-demographic group mostly associate with the outcome? Which group has the least contribution?
* What type of solution has been raised from the scientific community in terms of inducing diverse participants? ⇒ Solution or awareness of the limitations of the group?

https://utas.libguides.com/SystematicReviews/IdentifyConcepts

https://www.york.ac.uk/crd/SysRev/!SSL!/WebHelp/1_2_THE_REVIEW_PROTOCOL.htm

## 2. Preparation for the Review
### 2.1. Study Focus
* The figure below is a simplified illustration of a VGI process. 
    * Design stage includes establishing the appropriate goal and questions, preparing instructions, configuring the UI designs and frontends/backends, and test run the whole process. 
    * Once the settings are completed, the participants will contribute their work on a map. Geo-tagging places, adding names, or adding new features (e.g. buildings and roads) are the main tasks. 
    * Checking data quality is what the gatekeepers usually do. They check the positional, semantic accuracy 
    * Once the data is fully checked and validated with satellite imagery and relevant reports, the data are all good to be released to the public. 
* Amongst the entire process, we focus on the **participants** of VGI
<!--Because we believe that the data generated by participants can vary the outcomes-->

![](https://i.imgur.com/CTD5Q6J.jpg)

### 2.2. Conceptual Framework
* We developed a conceptual model to indicate the contextual map of participants in VGI by different social scales
* Social scales range from individual self to lifestyle factors (micro-scale), social and community level factors (meso-scale), and finally cultural and environmental factors (macro-scale)
    * Inherited factors: `Age`, `Sex`, `Ethnicity`
    * Individual lifestyle factors: `Income`, `Commute Time`, `Internet access` <!--(Can relate to time investment)-->
    * Social and community factors: `Education`, `Social and technical support`
    * Cultural and environmental factors: `Language`, `Censorship`
* The model suggests positive routes to make a more equal and diversified mapping culture (to the right). These include more diverse participation, increase of collaborative works, active interaction, and to be transparent of the distributions of participants
* However, for digitally divided mapping, more top-down approach will be common in the VGI projects, where participants only play a limited role

![Concept](https://i.imgur.com/BiYMZhF.jpg)

### 2.3. Building a team
* Speciallist in this area who can choose the appriate papers to include/exclude
* Statistician who can get involved in the extensive work of retrieving, screening and coding.
* The balance betewen topic and mothodological skills is important. 
* A team with specialties on the topic but without skills in review may 
    * struggle to complete the review at all; 
    * be tempted to limit their searching; 
    * or harbour a vested interest in a particular outcome of the review
* The opposite
    * missing important contextual details (particularly when developing the contextual framework)
    * neither understanding the broader theoretical or political position  nor understanding where the review fits in a particular body of knowledge

## 3. Inclusion Criteria
### 3.1. Settings
VGI projects

### 3.2. Perspective
under-represented volunteers

### 3.3. Intervention
more contribution in mapping

### 3.4. Comparison
socially biased environment where small sample of population represents all 

### 3.5. Evaluation
Diverse outcomes


## 4. Scoping for Review
### 4.1. Method
* [PRISMA Method](https://github.com/mrsensible/VGI/wiki/03.-Systematic-Review---PRISMA)
* Short for Preferred Reporting Items for Systematic Reviews and Meta-Analyses
* Contains a checklist
* Flow Diagramme
    * Identification - Screening - Eligibility - Included

### 4.2. Databased Used
* Web of Science
* SCOPUS
* ScienceDirect
* JSTOR
* EBSCO Technology & Engineering Research Databases

### 4.3. Filter
* Filtering period: 2000-2020
* Language: English
* Quality assessment: It would be better to have a few more reviewers to screen the literature
* **Keywords**:
    * VGI: The keywords include either full or an abbreviated term 





